@@ -24,8 +24,6 @@
 #include <sys/wait.h>
 #include <signal.h>
 #include <netdb.h>
-#include <curses.h>
-#include <term.h>
 #include <fcntl.h>
 #include <time.h>
 
